package com.ruoyi.basic.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.basic.mapper.HwLanguageMapper;
import com.ruoyi.basic.domain.HwLanguage;
import com.ruoyi.basic.service.IHwLanguageService;

/**
 * 语言信息Service业务层处理
 * 
 * @author xins
 * @date 2023-08-24
 */
@Service
public class HwLanguageServiceImpl implements IHwLanguageService 
{
    @Autowired
    private HwLanguageMapper hwLanguageMapper;

    /**
     * 查询语言信息
     * 
     * @param languageId 语言信息主键
     * @return 语言信息
     */
    @Override
    public HwLanguage selectHwLanguageByLanguageId(Long languageId)
    {
        return hwLanguageMapper.selectHwLanguageByLanguageId(languageId);
    }

    /**
     * 查询语言信息列表
     * 
     * @param hwLanguage 语言信息
     * @return 语言信息
     */
    @Override
    public List<HwLanguage> selectHwLanguageList(HwLanguage hwLanguage)
    {
        return hwLanguageMapper.selectHwLanguageList(hwLanguage);
    }

    /**
     * 新增语言信息
     * 
     * @param hwLanguage 语言信息
     * @return 结果
     */
    @Override
    public int insertHwLanguage(HwLanguage hwLanguage)
    {
        return hwLanguageMapper.insertHwLanguage(hwLanguage);
    }

    /**
     * 修改语言信息
     * 
     * @param hwLanguage 语言信息
     * @return 结果
     */
    @Override
    public int updateHwLanguage(HwLanguage hwLanguage)
    {
        return hwLanguageMapper.updateHwLanguage(hwLanguage);
    }

    /**
     * 批量删除语言信息
     * 
     * @param languageIds 需要删除的语言信息主键
     * @return 结果
     */
    @Override
    public int deleteHwLanguageByLanguageIds(Long[] languageIds)
    {
        return hwLanguageMapper.deleteHwLanguageByLanguageIds(languageIds);
    }

    /**
     * 删除语言信息信息
     * 
     * @param languageId 语言信息主键
     * @return 结果
     */
    @Override
    public int deleteHwLanguageByLanguageId(Long languageId)
    {
        return hwLanguageMapper.deleteHwLanguageByLanguageId(languageId);
    }
}
